.. _links:

Links
=====

* `Interactive Brokers <https://www.interactivebrokers.com>`_
* `Interactive Brokers Python API <http://interactivebrokers.github.io>`_
* `TWSAPI documentation <https://interactivebrokers.github.io/tws-api/>`_
* `TWSAPI user goup <https://groups.io/g/twsapi>`_
* `IB-insync user goup <https://groups.io/g/insync>`_
* `Dmitry's TWS API FAQ <https://dimon.ca/dmitrys-tws-api-faq/>`_
* `IBC <https://github.com/IbcAlpha/IBC>`_ for hands-free operation of TWS or gateway
